.. raw:: html

    <style> .red {color:#aa0060; font-weight:bold; font-size:18px} </style>

.. role:: red

.. This documentation was autogenerated using parselglossy. Editing by hand is not recommended.

================
Input parameters
================

- Keywords without a default value are **required**.
- Default values are either explicit or computed from the value of other keywords in the input.
- Sections where all keywords have a default value can be omitted.
- Predicates, if present, are the functions run to validate user input.

:red:`Keywords`
 :title: Title of the calculation. I had to write an extremely long documentation string for this one, as it is extremely important to let you know that this keyword will define the title of the calculation and, not having a default, you will be required to set it! 

  **Type** ``str``

 :an_integer: Some integer

  **Type** ``int``

  **Default** ``15``

 :float_list: A list of floats

  **Type** ``List[float]``

  **Default** ``[1.0, 2.0, 3.0]``

  **Predicates**
    - ``len(value) < 10``
    - ``max(value) < user['foo']['fooffa]['another_float']``

:red:`Sections`
 :foo: brilliant

  :red:`Keywords`
   :tragic: Title of the calculation.
  
    **Type** ``str``
  
    **Default** ``Wham! Bang! Pow! Let's Rock Out!``
  
   :a_float: A floating point number
  
    **Type** ``float``
  
    **Predicates**
      - ``value < 35.0``
      - ``value in user['float_list']``
  
  :red:`Sections`
   :Bar: A ba-bar section
  
      :red:`Keywords`
       :amazing: Title of the calculation.
      
        **Type** ``str``
      
        **Default** ``Bobson Dugnutt``
      
       :coolio: A cool bool
      
        **Type** ``bool``
      
        **Default** ``True``
      
 :fooffa: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec luctus elit ut posuere dictum. Proin ipsum libero, maximus vitae placerat a, bibendum viverra ante. 

  :red:`Keywords`
   :dwigt: An unusual name
  
    **Type** ``str``
  
    **Predicates**
      - ``len(value) < 80``
  
   :another_float: Another floating point number
  
    **Type** ``float``
  
    **Default** ``user['foo']['a_float'] * 2``
  